@@ -21,6 +21,7 @@ const FACET_FIELDS_DISPLAY_NAMES = Object.freeze({
     'closed': 'Discussion status',
     'dataSteward': 'Data Steward',
     'objectType': 'On object of type',
+    'typeBadges': 'AI Types',
 });
 
 
@@ -41,7 +42,21 @@ const DISPLAY_NAMES = Object.freeze({
         'python3': 'Python 3',
         'ir': 'R',
         'toree': 'Scala'
-    }
+    },
+    genAiTypes: {
+        'RETRIEVAL_AUGMENTED_LLM': 'Retrieval Augmented LLM',
+        'LLM_GENERIC': 'Fine-tuned LLM',
+    },
+    agentTypes: {
+        'PYTHON_AGENT': 'Code Agent',
+        'PLUGIN_AGENT': 'Plugin Agent',
+        'TOOLS_USING_AGENT': 'Visual Agent',
+    },
+    typeBadges: {
+        'AGENT': 'Agent',
+        'LLM': 'LLM',
+        'ML': 'ML',
+    },
 });
 
 /**
@@ -86,7 +101,7 @@ const DISPLAY_NAMES = Object.freeze({
                     );
                 case 'discussion': {
                     const obj = {
-                        type: _source.objectType.toUpperCase(),
+                        type: _source.tor.split('.')[1],
                         id: _source.objectId,
                         workspaceKey: _source.workspaceKey,
                         projectKey: _source.projectKey
@@ -117,6 +132,9 @@ const DISPLAY_NAMES = Object.freeze({
                     return rawType;
                 case 'knowledge_bank':
                     return 'retrievable_knowledge';
+                case 'gen_ai_model':
+                case 'agent':
+                    return 'saved_model';
                 default:
                     return indexableType;
             }
@@ -141,12 +159,12 @@ const DISPLAY_NAMES = Object.freeze({
         svc.getFlowLink = function (_type, _source, _contextProjectKey) {
             if (!_type || !_source) return;
             _type = svc.indexableTypeToTaggableType(_type, _source.type_raw);
-            return StateUtils.href.flowLinkFromProps(_type, _source.projectKey, _source.id, _contextProjectKey)
+            return StateUtils.href.flowLinkFromPropsNoZone(_type, _source.projectKey, _source.id, _contextProjectKey)
         };
 
-        svc.hasFlowLink = function (_type) {
-            _type = svc.indexableTypeToTaggableType(_type);
-            return FLOW_COMPUTABLE_TYPES.includes(_type.toUpperCase()) || _type === 'recipe' || _type === 'labeling_task';
+        svc.hasFlowLink = function (_type, type_raw) {
+            const taggable_type = svc.indexableTypeToTaggableType(_type, type_raw);
+            return FLOW_COMPUTABLE_TYPES.includes(taggable_type.toUpperCase()) || taggable_type === 'recipe' || taggable_type === 'labeling_task';
         };
 
         svc.itemToIcon = function (_type, _source, inList, size) {
@@ -154,6 +172,7 @@ const DISPLAY_NAMES = Object.freeze({
                 return;
             }
 
+            // note : this function has been "hacked" to also work with objects that do not come from the indexing, it should be split in two
             switch (_type) {
                 case 'dataset':
                     return inList ? $filter('typeToIcon')(_source.type_raw, size) : $filter('datasetTypeToIcon')(_source.type_raw, size);
@@ -161,6 +180,12 @@ const DISPLAY_NAMES = Object.freeze({
                     return $filter('typeToIcon')(_source.type_raw, size);
                 case 'web_app':
                     return $filter('subTypeToIcon')(_source.subtype || _source.type_raw, _type, size);
+                case 'gen_ai_model':
+                    return $filter('savedModelSubtypeToIcon')(null, null, null, _source.type_raw, null, size);
+                case 'agent':
+                    return $filter('savedModelSubtypeToIcon')(null, null, null, _source.type ? _source.type[0] : '', null, size);
+                case 'agent_tool':
+                    return $filter('agentToolTypeToIcon')(_source.type_raw || _source.agentToolType, size);
                 case 'saved_model': {
                     return $filter('savedModelSubtypeToIcon')(_source.taskType, _source.backendType, _source.predictionType, _source.savedModelType, _source.proxyModelProtocol || _source.externalSavedModelType, size);
                 }
@@ -173,12 +198,14 @@ const DISPLAY_NAMES = Object.freeze({
             if (!_type || !_source) return;
             if (_type == 'insight') {
                 return $filter('insightTypeToColor')(_source.type_raw) + ' insight-icon';
-            } else if (_type == 'recipe') {
+            } else if (_type === 'recipe') {
                 return $filter('recipeTypeToColorClass')(_source.type_raw);
-            } else if (_type == 'saved_model') {
+            } else if (_type === 'saved_model') {
                 return $filter('savedModelTypeToClassColor')(_source.savedModelType);
-            } else if (_type == 'chart') {
+            } else if (_type === 'chart') {
                 return $filter('chartTypeToColor')(_source.objectType);
+            } else if (_type === 'agent' || _type === 'gen_ai_model') {
+                return 'llm-saved-model';
             } else {
                 return _type.toLowerCase();
             }
@@ -187,10 +214,9 @@ const DISPLAY_NAMES = Object.freeze({
 
 
 
-app.controller('CatalogItemsController', function($controller, $scope, $injector, $state, $stateParams, $route,
-    $q, $location, $filter, $timeout,
-    DataikuAPI, CreateModalFromTemplate, WT1, TopNav, DatasetsService, StateUtils, Debounce,
-    CatalogUtils, Navigator, DashboardUtils, CachedAPICalls, CatalogItemService, TypeMappingService, TaggingService) {
+app.controller('CatalogItemsController', function($controller, $scope, $state, $stateParams, $filter,
+    DataikuAPI, CreateModalFromTemplate, StateUtils, CatalogUtils, DashboardUtils, CatalogItemService,
+    TypeMappingService, TaggingService, AgentToolService) {
 
     const overridenCatalogUtils = {
         getHash: CatalogUtils.getHash,
@@ -262,9 +288,9 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
 
     $scope.goToConnectionsExplorer = function() {
         if ($state.includes('projects.project')) {
-            $state.go('projects.project.datacatalog.connectionexplorer');
+            $state.go('projects.project.datacatalog.database-explorer');
         } else {
-            $state.go('datacatalog.connectionexplorer');
+            $state.go('homeV2.data-catalog.database-explorer');
         }
     };
 
@@ -305,9 +331,10 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
     $scope.displayItemTypeFacet = !$state.current.name.includes('datacatalog');
 
     $scope.mapItemToIcon = function(item, size) {
+        // those icons are not mapped yet so let's do something dirty for now, otherwise it will have impact on the whole application
         if (item.key === 'chart') {
             // TODO : remove this hack when implementing [sc-243801]
-            return 'dku-icon-chart-' + size; // this icon is not mapped yet so let's do something dirty for now, otherwise it will have impact on the whole application
+            return 'dku-icon-chart-' + size;
         }
         return TypeMappingService.mapTypeToIcon(item.key, size);
     }
@@ -391,6 +418,14 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
         }
     }
 
+
+    $scope.getTorFromSource = (src) => ({
+        type: src.tor.split('.')[1],
+        id: src.objectId,
+        projectKey: src.projectKey,
+        workspaceKey: src.workspaceKey,
+    });
+
     $scope.getLink = function (input, discussionId) {
         if (!input) return;
         return CatalogItemService.getLink(input._type, input._source, discussionId);
@@ -418,7 +453,7 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
 
     $scope.hasFlowLink = function(input) {
         if (!input) return;
-        return CatalogItemService.hasFlowLink(input._type, input._source);
+        return CatalogItemService.hasFlowLink(input._type, input._source.type_raw);
     };
 
     $scope.formatFacetField = function(field) {
@@ -432,7 +467,8 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
             case 'projectKey.raw':
                 return projectNames[value] || value;
             case '_type':
-                return $filter('capitalize')(value.replace(/_/g, " "));
+            case 'objectType':
+                return $filter('capitalize')(userFriendlyType(value));
             case 'user':
             case 'owner':
             case 'dataSteward':
@@ -452,6 +488,12 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
                         return DISPLAY_NAMES.recipeTypes[value] || $filter('capitalize')(value.replace(/_/g, " "));
                     case 'notebook':
                         return DISPLAY_NAMES.notebookTypes[value];
+                    case 'gen_ai_model':
+                        return DISPLAY_NAMES.genAiTypes[value];
+                    case 'agent':
+                        return DISPLAY_NAMES.agentTypes[value] || value;
+                    case 'agent_tool':
+                        return AgentToolService.getAgentToolTypesUiDataForType(value)?.label || value;
                     case 'saved_model':
                         return $filter('capitalize')(value);
                     case 'model_evaluation_store':
@@ -466,10 +508,24 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
             case 'partitioned':
             case 'isInDataCollection':
                 return value === 0 ? 'No' : 'Yes';
+            case 'typeBadges':
+                return DISPLAY_NAMES.typeBadges[value] || value;
         }
+
         return value;
     };
 
+    function userFriendlyType(indexableType) {
+        switch (indexableType) {
+            case 'lambda_service':
+                return 'API Service';
+            case 'gen_ai_model':
+                return 'gen AI model';
+            default:
+                return indexableType.replace(/_/g, " ");
+        }
+    };
+
     // Override to allow to search for project by both name and key in the project list facet
     $scope.facetValueMatching = function(field) {
         return function(search) {
@@ -500,7 +556,7 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
             const src = item._source;
             // Comes from _source, encode HTML entities in order to display attributes like <stuff
             const topic = (item.highlight && item.highlight['discussions.topic']) ? item.highlight['discussions.topic'][0] : ($filter('escapeHtml')(((src.discussions && src.discussions.length && src.discussions[0].topic) ? src.discussions[0].topic : "Unnamed discussion")));
-            const title = topic + " <small>on " + src.objectType.replace('_', ' ') + "</small> " + $filter('escapeHtml')(src.objectName);
+            const title = topic + " <small>on " + userFriendlyType(src.objectType) + "</small> " + $filter('escapeHtml')(src.objectName);
             return title;
         }
 
@@ -508,7 +564,7 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
             const src = item._source;
             // Comes from _source, encode HTML entities in order to display attributes like <stuff
             const name = $scope.encodeItemName(item) || 'Untitled chart'; // TODO : change done near release. We should factorize the untitled behavior to all types
-            const title = name + " <small>on " + src.objectType.replace('_', ' ') + "</small> " + $scope.encodeItemObjectName(item);
+            const title = name + " <small>on " + userFriendlyType(src.objectType) + "</small> " + $scope.encodeItemObjectName(item);
             return title;
         }
         return $scope.encodeItemName(item);
@@ -552,7 +608,7 @@ app.controller('CatalogItemsController', function($controller, $scope, $injector
                 strippedAttachments = item.highlight['attachments.displayName'].map(str => str.replace(/<\/?em>/g, ''));
             }
             angular.forEach(item._source.attachments, function(attachment) {
-                const index = strippedAttachments.indexOf(attachment.name);
+                const index = strippedAttachments.indexOf(attachment.displayName);
                 if (index == -1) {
                     item.highlightedAttachments.push(attachment);
                 } else {
@@ -717,6 +773,12 @@ app.service('CatalogRefreshUtils', function($state, StateUtils) {
                     streamingEndpointId: element.name,
                     projectKey: projectKey
                 });
+            case "RETRIEVABLE_KNOWLEDGE":
+               return $state.href("projects.project.retrievableknowledges.retrievableknowledge.settings", {
+                   projectKey,
+                   retrievableKnowledgeId: element.id,
+                   '#': 'core-settings',
+               });
             default:
                 throw "Incorrect or missing flow computable type";
         }
@@ -763,9 +825,11 @@ app.component('relatedByType', {
 app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuAPI, CachedAPICalls, $sce,
                                                     CatalogItemService, ActivityIndicator, ExposedObjectsService,
                                                     AppConfig, FLOW_COMPUTABLE_TYPES, CatalogRefreshUtils,
-                                                    QuickSharingWT1EventsService) {
+                                                    QuickSharingWT1EventsService, SavedModelsService, AgentToolEnrichmentService) {
     $scope.getLinkForElement = CatalogRefreshUtils.getLinkForElement;
 
+    $scope.resolveObjectSmartId = resolveObjectSmartId;
+
     $scope.$watch("formatted_items", function() {
         if ($scope.formatted_items && $scope.selected && $scope.selected.item) {
             for (let i = 0; i < $scope.formatted_items.length; i++) {
@@ -800,20 +864,40 @@ app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuA
             });
         }
 
-        if (item._type === 'insight') {
-            $scope.insightData = null;
-            DataikuAPI.dashboards.insights.get(item._source.projectKey, item._source.id)
-                .success(function(response) {})
-                .error(setErrorInScope.bind($scope));
-        }
-
-        else if (item._type === 'dataset') {
+        if (item._type === 'dataset') {
             CatalogRefreshUtils.computeDatasetInputsOutputsByType(item);
-        }
-
-        else if (item._type === 'recipe' || item._type === "labeling_task") {
+        } else if (item._type === 'recipe' || item._type === 'labeling_task') {
             item.splitOutputs = CatalogRefreshUtils.reformatNames(item._source.outputs);
             item.splitInputs = CatalogRefreshUtils.reformatNames(item._source.inputs);
+        } else if (item._type === 'gen_ai_model' || item._type === 'agent' || item._type === 'saved_model') {
+            DataikuAPI.savedmodels.getFullInfo(item._source.projectKey, item._source.id).success(function(response) {
+                    item.model = response.model;
+                    item.status = response.status;
+                    item.creatingRecipe = response.creatingRecipe;
+                    item.recipes = response.recipes;
+                    item.creatingContinuousRecipe = response.creatingContinuousRecipe;
+                    item.creatingLabelingTask = response.creatingLabelingTask;
+
+                    SavedModelsService.enrichSavedModelObject(item, $scope)
+                })
+                .error(setErrorInScope.bind($scope));
+        } else if (item._type === 'agent_tool') {
+            DataikuAPI.agentTools.getFullInfo(item._source.projectKey, item._source.id).success(function(response) {
+                    AgentToolEnrichmentService.enrichAgentToolObject(response.agentTool, $scope);
+                    item.summary = response.agentTool.summary;
+                })
+                .error(setErrorInScope.bind($scope));
+        } else if (item._type === 'lambda_service') {
+
+            DataikuAPI.lambda.services.getSummary(item._source.projectKey, item._source.id).success(function(response) {
+                    item.object = response.object
+                    item.packages = response.packages
+
+                    SavedModelsService.listAPIServiceableModels(item._source.projectKey).then(function(serviceableModels) {
+                        $scope.availableSavedModels = serviceableModels;
+                    }).catch(setErrorInScope.bind($scope));
+                })
+                .error(setErrorInScope.bind($scope));
         }
 
         $scope.navigatorFn = CatalogItemService.hasNavigator(item._type) ? CatalogItemService.openNavigator(item._type, item._source) : false;
