@@ -13,11 +13,11 @@
                     if (!noNotification) {
                         ActivityIndicator.success('Saved!');
                     }
-                    $scope.$broadcast('objectTimelineChanged');
                     dashboard.listed = !dashboard.listed;
                     if ($scope.origDashboard) {
                         $scope.origDashboard.listed = dashboard.listed;
                     }
+                    $scope.$broadcast('objectTimelineChanged');
                 }).error(setErrorInScope.bind($scope));
         }
 
@@ -97,6 +97,11 @@
             });
         };
 
+        $scope.share = function() {
+            CreateModalFromTemplate('/templates/dashboards/share-dashboard-modal.html', $scope, 'ShareDashboardModalController', function(newScope) {
+                newScope.init($scope.dashboard);
+            });
+        };
 
         $scope.saveAndCopy = function(dashboard, callBackFund) {
             $scope.saveDashboard().then(function() {
@@ -172,8 +177,12 @@
 
         $scope.$on('saveDashboard', () => $scope.saveDashboard());
 
-        $rootScope.$on('dashboard-edit-action-request', (_, options) => {
+        const unregisterDashboardEditActionRequestEvent = $rootScope.$on('dashboard-edit-action-request', (_, options) => {
             $scope.editActionRequested = options;
         });
+
+        $scope.$on('$destroy', () => {
+            unregisterDashboardEditActionRequestEvent();
+        });
     });
 })();
