@@ -21,12 +21,13 @@
         };
     });
 
-    app.controller('NewInsightModalController', function($scope, $controller, $stateParams, $q, $filter,
-				   DataikuAPI, INSIGHT_TYPES, DashboardUtils, DSSVisualizationThemeUtils, $rootScope) {
+    app.controller('NewInsightModalController', function($scope, $stateParams, $q, $filter,
+				   DataikuAPI, INSIGHT_TYPES, DashboardUtils, $rootScope, translate) {
 
         $scope.DashboardUtils = DashboardUtils;
         $scope.insightTypes = INSIGHT_TYPES;
         $scope.displayableInsightType = null;
+        $scope.insightTypeTranslationKey = null;
 
         $scope.uiState = $scope.uiState || {};
         $scope.uiState.modalTab = 'new';
@@ -48,6 +49,11 @@
             filterInsights();
         });
 
+        $scope.$watchGroup(['inDashboard', 'displayableInsightType'], function() {
+            $scope.insightTypeTranslationKey = $scope.getInsightTypeTranslationKey();
+            $scope.modalTitle = $scope.getModalTitle();
+        });
+
         function filterInsights() {
             $scope.filteredInsights = $filter('filter')($scope.insights, { type: $scope.insight.type });
             $scope.noInsightOfSelectedType = !$scope.filteredInsights || $scope.filteredInsights.length == 0;
@@ -74,10 +80,37 @@
         };
 
         $scope.simpleTileTypes = {
-            text: { name: 'Text', desc: 'Zone of text' },
-            image: { name: 'Image', desc: 'Upload an image' },
-            iframe: { name: 'Web Content', desc: 'Embedded web page' },
-            group: { name: 'Group', desc: 'Tile that can contain others' }
+            text: {
+                name: 'Text',
+                desc: 'Zone of text',
+                i18nNameKey: 'DASHBOARD.TILES.TEXT.NAME',
+                i18nDescKey: 'DASHBOARD.TILES.TEXT.DESC'
+            },
+            image: {
+                name: 'Image',
+                desc: 'Upload an image',
+                i18nNameKey: 'DASHBOARD.TILES.IMAGE.NAME',
+                i18nDescKey: 'DASHBOARD.TILES.IMAGE.DESC'
+
+            },
+            iframe: {
+                name: 'Web Content',
+                desc: 'Embedded web page',
+                i18nNameKey: 'DASHBOARD.TILES.WEB_CONTENT.NAME',
+                i18nDescKey: 'DASHBOARD.TILES.WEB_CONTENT.DESC'
+
+            },
+            group: {
+                name: 'Group',
+                desc: 'Tile that can contain others',
+                i18nNameKey: 'DASHBOARD.TILES.GROUP.NAME',
+                i18nDescKey: 'DASHBOARD.TILES.GROUP.DESC'
+
+            }
+        };
+
+        $scope.sourceTypePlaceholderOption = {
+            noneSelectedText: translate('DASHBOARD.NEW_TILE_MODAL.SOURCE_TYPE', 'Source type')
         };
 
         $scope.setDashboardCreationId = function(dashboardId) {
@@ -86,19 +119,18 @@
 
         $scope.getModalTitle = function() {
             if ($scope.inDashboard) {
-                const insightType = $scope.displayableInsightType ? $scope.displayableInsightType.toLowerCase() : 'tile';
-                return insightType === 'filters' ? 'Add filters to slide' : 'Add ' + insightType + ' to dashboard';
+                const insightTypeName = $scope.displayableInsightType ? $scope.displayableInsightType.toLowerCase() : 'tile';
+                return translate(`DASHBOARD.NEW_TILE_MODAL.ADD_${$scope.insightTypeTranslationKey}_TO_DASHBOARD`, `Add ${insightTypeName} to dashboard`);
             }
-            return $scope.displayableInsightType ? 'New ' + $scope.displayableInsightType + ' insight' : 'New insight';
+            const insightTypeName = $scope.displayableInsightType ? $scope.displayableInsightType.toLowerCase() : 'insight';
+            return translate(`DASHBOARD.NEW_TILE_MODAL.NEW_${$scope.insightTypeTranslationKey}`, `New ${insightTypeName}`);
         };
 
-        $scope.getModalStepHeaderTitle = function() {
-            return $scope.displayableInsightType.toLowerCase() === 'filters' ?
-                'Select origin of the source dataset' : 'Type selection';
-        };
-
-        $scope.isFiltersSourceSelectionStep = function() {
-            return $scope.displayableInsightType && $scope.displayableInsightType.toLowerCase() === 'filters' && !$scope.uiState.source;
+        $scope.getInsightTypeTranslationKey = function() {
+            if ($scope.inDashboard) {
+                return $scope.displayableInsightType ? $scope.displayableInsightType.replaceAll(' ', '_').toUpperCase() : 'TILE';
+            }
+            return $scope.displayableInsightType ? $scope.displayableInsightType.replaceAll(' ', '_').toUpperCase() : 'INSIGHT';
         };
 
         $scope.resetModal = function() {
@@ -116,6 +148,7 @@
             };
 
             $scope.displayableInsightType = null;
+            $scope.insightTypeTranslationKey = null;
 
             $scope.filter = {};
 
@@ -150,6 +183,7 @@
             $scope.insight.type = type;
             $scope.canPickExistingInsight = DashboardUtils.canListInsight($scope.insight);
             $scope.displayableInsightType = DashboardUtils.getInsightHandler(DashboardUtils.getInsightTypeGroup(type)).name;
+            $scope.insightTypeTranslationKey = $scope.getInsightTypeTranslationKey();
             if (type === 'static_file') {
                 $scope.pointerMode.isPointerMode = true;
             }
@@ -633,15 +667,14 @@
         /*
          * UI
          */
-
         const pagesLabels = {};
         $scope.getPageLabel = function(dashboard, page) {
             if (page.id && pagesLabels[page.id]) {
                 return pagesLabels[page.id];
             }
             let pageLabel = '';
-            if (page.title) {
-                pageLabel = page.title;
+            if (page.displayedTitle) {
+                pageLabel = page.displayedTitle;
             } else {
                 pageLabel = 'Page ' + (dashboard.pages.indexOf(page) + 1);
             }
