@@ -27,9 +27,10 @@
                     if (!nv) return;
                     update();
                 });
-                $rootScope.$watch("userPicturesHash", function() {
+                const userPicturesHashWatcherUnsubscribe = $rootScope.$watch("userPicturesHash", function() {
                     update();
-                })
+                });
+                scope.$on('$destroy', userPicturesHashWatcherUnsubscribe);
             }
         };
     });
@@ -447,7 +448,7 @@
     });
 
 
-    app.factory("ProgressStackMessageBuilder", function($filter) {
+    app.factory("ProgressStackMessageBuilder", function($filter, translate) {
         // caution: you can have both hasResult == false and response.progress == null
         // => with a remote future (executed in the fek), there are some extra steps
         // at the end of the computation, where the backend will not have progress for
@@ -537,14 +538,15 @@
                         let lastStackEltDuration = $filter('friendlyDurationShort')(lastStackElt.msSinceStart);
                         if (isHtml) {
                             lastStackEltDuration = lastStackEltDuration.replace('<', '&lt;');
-                            messageStack[k] = messageStack[k] + "<div><small>Started " + lastStackEltDuration + " ago</small></div>";
+                            messageStack[k] = `${messageStack[k]}<div><small>${translate("PROGRESS_STACK_MESSAGES.STARTED", `Started ${lastStackEltDuration} ago`, { time: lastStackEltDuration })}</small></div>`;
                         } else {
-                            messageStack[k] = messageStack[k] + " - Started " + lastStackEltDuration + " ago";
+                            messageStack[k] = `${messageStack[k]} - ${translate("PROGRESS_STACK_MESSAGES.STARTED", `Started ${lastStackEltDuration} ago`, { time: lastStackEltDuration })}`;
                         }
                     }
                     return isHtml ? messageStack.join("<br />") : messageStack.join(" - ");
                 } else {
-                    return isHtml ? "<div class='waiting__message-text-content'>Please wait...</div>" : "Please wait...";
+                    const pleaseWaitText = translate("PROGRESS_STACK_MESSAGES.WAIT", "Please wait...")
+                    return isHtml ? `<div class='waiting__message-text-content'>${pleaseWaitText}</div>` : pleaseWaitText;
                 }
             }
         };
@@ -575,12 +577,6 @@
                         DataikuAPI.futures.abort(scope.response.jobId).error(setErrorInScope.bind(scope));
                     }
                 };
-                $rootScope.$on("futureModalOpen", function() {
-                    scope.futureModalOpen = true;
-                });
-                $rootScope.$on("futureModalClose", function() {
-                    scope.futureModalOpen = false;
-                });
             }
         };
     });
