@@ -14,6 +14,7 @@ app.service('ExposedObjectsService', function($rootScope, $stateParams, Taggable
     };
 
     function openSingleObjectModal(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, displayMode, wt1Context) {
+        // TODO : candidate for Angular migration
         return CreateModalFromTemplate("/templates/projects/expose-single-object-modal.html", $rootScope, "ExposeSingleObjectModalController", function(modalScope) {
             modalScope.init(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, displayMode, wt1Context);
         });
@@ -50,7 +51,7 @@ app.service('ExposedObjectsService', function($rootScope, $stateParams, Taggable
 
     // API call & WT1 event for sharing an object.
     // Does not handle errors, does not give visual feedback to the user
-    this.doExposeSingleObject = (objectType, objectProjectKey, objectId, targetProjectKey, objectDisplayName, isAlreadyQuickShared, showActivityIndicator, wt1Context) => {
+    this.doExposeSingleObject = (objectType, objectProjectKey, objectId, targetProjectKey, objectDisplayName, isAlreadyQuickShared, showActivityIndicatorOnSuccess, wt1Context) => {
         return DataikuAPI.projects
             .addExposedObject(objectProjectKey, objectType, objectId, targetProjectKey, $stateParams.zoneId)
             .success((data) => {
@@ -58,7 +59,8 @@ app.service('ExposedObjectsService', function($rootScope, $stateParams, Taggable
                     this.sendWT1EventForDoExposeSingleObject(objectType, objectProjectKey, objectId, targetProjectKey, isAlreadyQuickShared, wt1Context)
                 }
 
-                if(showActivityIndicator) {
+                // we always show the activity indicator when not in success
+                if (data.severity !== 'SUCCESS' || showActivityIndicatorOnSuccess) {
                     const linkMessage = `View ${sanitize(objectDisplayName)} in flow`;
                     const linkUrl = StateUtils.href.flowLinkFromProps(objectType, objectProjectKey, objectId, targetProjectKey);
                     const message = `${data.title} <a href="${linkUrl}">${linkMessage}</a>.`;
@@ -294,13 +296,20 @@ app.controller("RequestSharingModalController", function($scope, DataikuAPI, Act
 });
 
 
-app.controller("ExposeSingleObjectModalController", function($scope, $rootScope, DataikuAPI, ActivityIndicator, CatalogItemService, QuickSharingWT1EventsService, $q, $filter, translate) {
+app.controller("ExposeSingleObjectModalController", function($scope, $rootScope, DataikuAPI, ActivityIndicator, CatalogItemService, QuickSharingWT1EventsService, $q, $filter, translate, Ng2ProjectsService, StateUtils) {
     $scope.init = function(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, displayMode, wt1Context) {
+        $scope.tor = {
+            id: objectId,
+            projectKey: objectProjectKey,
+            type: objectType
+        };
         $scope.objectProjectKey = objectProjectKey;
         $scope.objectDisplayName = objectDisplayName;
         $scope.notFlowItem = ["WEB_APP", "SCENARIO", "JUPYTER_NOTEBOOK", "REPORT"].includes(objectType); // those items types will show a warning saying they will only be visible for dashboards + hide quick-share option (as quickshare is only supported to flow items)
         $scope.canManageExposedElements = canManageExposedElements;
         $scope.showQuickSharingUI = !$scope.notFlowItem && canManageExposedElements && $rootScope.appConfig.quickSharingElementsEnabled && displayMode === 'share';
+        const globalPermissions = $rootScope.appConfig.globalPermissions;
+        $scope.canCreateProject = (globalPermissions.mayCreateProjects || globalPermissions.mayCreateProjectsFromMacros);
 
         // Wording
         $scope.modalTitle = displayMode === 'share'
@@ -311,6 +320,8 @@ app.controller("ExposeSingleObjectModalController", function($scope, $rootScope,
             finishedLoading: false,
             quickSharingEnabled: false,
             newProjectsSharedTo: [],
+            useInProjectOption: 'EXISTING',
+            hadShareErrorAfterProjectCreation: false
         }
 
         let hasBeenSaved = false;
@@ -320,6 +331,30 @@ app.controller("ExposeSingleObjectModalController", function($scope, $rootScope,
 
         QuickSharingWT1EventsService.onModalOpen(objectType, objectProjectKey, objectId);
 
+        function refreshAvailableProjects() {
+            DataikuAPI.taggableObjects.listAccessibleObjects(null, 'PROJECT').then((resp) => {
+                $scope.availableProjects = updateAvailableProjects(resp.data, objectProjectKey, originalTargetProjectKeys)
+            }).catch(setErrorInScope.bind($scope));
+        };
+
+        function updateAvailableProjects(accessibleProjects, objectProjectKey, originalTargetProjectKeys) {
+            // setup for the project dropdown
+            return accessibleProjects
+                .filter(item => item.object.canWriteProjectContent) // theoretically a manage sharing user could share to a readable project only, but not through that UI / api route.
+                .map(item => {
+                    if (item.smartId === objectProjectKey) {
+                        item.usable = false;
+                        item.usableReason = `Cannot share to the project this ${$filter('niceTaggableType')(objectType)} originates from`;
+                    } else if (originalTargetProjectKeys.includes(item.smartId)) {
+                        item.usable = false;
+                        item.usableReason = 'Already shared to this project';
+                    } else {
+                        item.usable = true;
+                    }
+                    return item;
+                });
+        }
+
         $q.all([
             DataikuAPI.projects.getObjectExposition(objectProjectKey, objectType, objectId),
             DataikuAPI.taggableObjects.listAccessibleObjects(null, 'PROJECT'),
@@ -330,34 +365,23 @@ app.controller("ExposeSingleObjectModalController", function($scope, $rootScope,
             originalRules = objectExposition.rules.slice();
             $scope.uiState.quickSharingEnabled = originalQuickSharing;
 
-            // setup for the project dropdown
-            $scope.availableProjects = accessibleProjects
-                .filter(item => item.object.canWriteProjectContent) // theoretically a manage sharing user could share to a readable project only, but not through that UI / api route.
-                .map(item => {
-                    if(item.smartId === objectProjectKey) {
-                        item.usable = false;
-                        item.usableReason = `Cannot share to the project this ${$filter('niceTaggableType')(objectType)} originates from`;
-                    } else if(originalTargetProjectKeys.includes(item.smartId)) {
-                        item.usable = false;
-                        item.usableReason = 'Already shared to this project';
-                    } else {
-                        item.usable = true;
-                    }
-                    return item;
-                });
-
+            $scope.availableProjects = updateAvailableProjects(accessibleProjects, objectProjectKey, originalTargetProjectKeys);
             $scope.uiState.finishedLoading = true;
         }).catch(setErrorInScope.bind($scope))
 
         $scope.canSave = function() {
             return $scope.uiState.finishedLoading && (
-                $scope.uiState.quickSharingEnabled != originalQuickSharing
-                || $scope.uiState.newProjectsSharedTo.length > 0
+                    ($scope.uiState.quickSharingEnabled != originalQuickSharing || $scope.uiState.newProjectsSharedTo.length > 0)
             );
         }
 
+        $scope.canNext = function() {
+            return $scope.uiState.finishedLoading && angular.isDefined($scope.uiState.projectCreationOption) && $scope.canCreateProject;
+        }
+
         $scope.save = function() {
             hasBeenSaved = true;
+            $scope.uiState.hadShareErrorAfterProjectCreation = false;
             QuickSharingWT1EventsService.onModalSave(objectType, objectProjectKey, objectId);
 
             const newProjectsSharedTo = $scope.uiState.newProjectsSharedTo.map(item => item.smartId);
@@ -396,6 +420,37 @@ app.controller("ExposeSingleObjectModalController", function($scope, $rootScope,
                 .error(setErrorInScope.bind($scope));
         };
 
+        $scope.next = function() {
+            // create a new project
+            const runnable = $scope.uiState.projectCreationOption.runnable;
+            const wt1Context = { createdFromShareModal: true};
+            const openNewProjectModal = runnable
+            ? Ng2ProjectsService.openNewProjectCreationMacroModal(runnable, false, wt1Context)
+            : Ng2ProjectsService.openNewBlankProjectModal('', false, wt1Context);
+
+            openNewProjectModal.then((newProjectKey) => {
+                hasBeenSaved = true;
+                $scope.uiState.hadShareErrorAfterProjectCreation = false;
+                if (newProjectKey) {
+                    DataikuAPI.projects.addExposedObject($scope.tor.projectKey, $scope.tor.type, $scope.tor.id, newProjectKey).then(() => {
+                        StateUtils.go.flowLinkFromProps($scope.tor.type, $scope.tor.projectKey, $scope.tor.id, newProjectKey);
+                    }).catch((resp) => {
+                        setErrorInScope.bind($scope)(resp.data, resp.status, resp.headers);
+                        handleShareErrorAfterProjectCreation();
+                    });
+                } else {
+                    // the project has been created but no project key was returned => this is a macro that does not return a project key, we can't share the element to the project
+                    // this will never happen in a prod environment though
+                    handleShareErrorAfterProjectCreation();
+                }
+            });
+        };
+
+        function handleShareErrorAfterProjectCreation() {
+            $scope.uiState.hadShareErrorAfterProjectCreation = true;
+            refreshAvailableProjects();
+        }
+
         $scope.$on("$destroy", function() {
             if (!hasBeenSaved) {
                 QuickSharingWT1EventsService.onModalCancel(objectType, objectProjectKey, objectId);
