@@ -111,7 +111,6 @@ app.service('SubFlowCopyService', function($rootScope, $q, $state, $stateParams,
                 targetMode: 'CURRENT_PROJECT',
                 targetProjectKey: '',
                 targetProjectFolder: null, // will be initialized asynchronously
-                targetProjectFolderId: '', // will be initialized asynchronously
                 datasetNames: {},
                 streamingEndpointNames: {},
                 flowZoneNames: {}
@@ -316,12 +315,19 @@ app.service('SubFlowCopyService', function($rootScope, $q, $state, $stateParams,
                 setErrorInScope.apply(modalScope, args);
             });
 
+            modalScope.toCopySubflowApiOptions = function(options) {
+                return {
+                    ...options,
+                    targetProjectFolder: undefined,
+                    targetProjectFolderId: options.targetProjectFolder ? options.targetProjectFolder.id : '',
+                }
+            }
 
             modalScope.test = function() {
                 const deferred = $q.defer();
                 delete modalScope.messages;
                 resetErrorInScope(modalScope);
-                DataikuAPI.flow.refactoring.testCopySubFlow(modalScope.selectedObjects, modalScope.options, $stateParams.projectKey).success(function(data) {
+                DataikuAPI.flow.refactoring.testCopySubFlow(modalScope.selectedObjects, modalScope.toCopySubflowApiOptions(modalScope.options), $stateParams.projectKey).success(function(data) {
                     modalScope.messages = data;
                     if (data.anyMessage) {
                         deferred.reject();
@@ -341,8 +347,7 @@ app.service('SubFlowCopyService', function($rootScope, $q, $state, $stateParams,
             };
 
             function performCopy() {
-                modalScope.options.targetProjectFolderId = modalScope.options.targetProjectFolder ? modalScope.options.targetProjectFolder.id : '';
-                DataikuAPI.flow.refactoring.copySubFlow(modalScope.selectedObjects, modalScope.options, $stateParams.projectKey).success(function(data) {
+                DataikuAPI.flow.refactoring.copySubFlow(modalScope.selectedObjects, modalScope.toCopySubflowApiOptions(modalScope.options), $stateParams.projectKey).success(function(data) {
                     $rootScope.$emit('stopAction');
                     modalScope.resolveModal();
 
