@@ -7,7 +7,7 @@
     /**
      * (!) This service previously was in static/dataiku/js/simple_report/common/data.js
      */
-    function ChartDataUtils(ChartDimension, ChartUADimension, Fn, $filter, CHART_DATES_LABELS, ChartLabels, CHART_TYPES, ChartsStaticData, translate) {
+    function ChartDataUtils(ChartDimension, ChartMeasure, ChartUADimension, Fn, $filter, CHART_DATES_LABELS, ChartLabels, CHART_TYPES, ChartsStaticData, translate, CHART_VARIANTS) {
         /**
          * Returns true if:
          * <ul>
@@ -156,12 +156,13 @@
             /**
              * Returns the min & max values across all dimensions & all measures for the two display axes
              * @param {ChartDef.java} chartDef
-             * @param {PivotTableTensorResponse.java} data
+             * @param {ChartTensorDataWrapper} chartData
+             * @param {string} mainAxisName - id of the main axis
              * @param {Array} timestampRange min and max used to filter the data based on their timestamp
              * @param {Boolean} includeEmptyBins - whether or not to include empty bins
              * @return {Object} { y1: { extent: [Number, Number], onlyPercent: Boolean }, y2: { extent: [Number, Number], onlyPercent: Boolean }, recordsCount: Number, pointsCount: Number }
              */
-            getMeasureExtents: function(chartDef, data, timestampRange, includeEmptyBins) {
+            getMeasureExtents: function(chartDef, chartData, mainAxisName, timestampRange, includeEmptyBins) {
                 const result = {
                     [ChartsStaticData.LEFT_AXIS_ID]: buildDefaultExtent(),
                     [ChartsStaticData.RIGHT_AXIS_ID]: buildDefaultExtent(),
@@ -169,20 +170,33 @@
                     pointsCount: 0
                 };
 
-                const mainAxisLabel = data.axisLabels[0];
-                const countsTensor = data.counts.tensor;
+                const countsTensor = chartData.data.counts.tensor;
+                const mainAxisLabels = chartData.getAxisLabels(mainAxisName);
                 chartDef.genericMeasures.forEach(function(measure, measureIndex) {
-                    const aggregationTensorForMeasure = data.aggregations[measureIndex].tensor;
-                    const measureExtent = d3.extent(
-                        filterTensorOnTimestampRange(aggregationTensorForMeasure, mainAxisLabel, countsTensor, timestampRange, includeEmptyBins)
-                    );
+                    let measureExtent = [];
+                    const measureData = chartData.data.aggregations[measureIndex];
+                    if (ChartMeasure.isRealUnaggregatedMeasure(measure)) {
+                        const filterTensor = (t) => filterTensorOnTimestampRange(t, mainAxisLabels, countsTensor, timestampRange, includeEmptyBins);
+                        measureExtent = ChartMeasure.getUaMeasureExtent(measureData, filterTensor);
+                    } else {
+                        const filteredTensor = filterTensorOnTimestampRange(measureData.tensor, mainAxisLabels, countsTensor, timestampRange, includeEmptyBins);
+                        measureExtent = d3.extent(
+                            chartDef.variant === CHART_VARIANTS.waterfall
+                                ? filteredTensor.reduce((acc, value) => {
+                                    const cumulativeValue = acc[acc.length - 1] || 0;
+                                    acc.push(cumulativeValue + value);
+                                    return acc;
+                                }, [])
+                                : filteredTensor
+                        );
+                    }
                     const axis = measure.displayAxis === 'axis1' ? ChartsStaticData.LEFT_AXIS_ID : ChartsStaticData.RIGHT_AXIS_ID;
                     result[axis].onlyPercent = result[axis].onlyPercent && ChartDimension.isPercentScale([measure]);
                     result[axis].extent[0] = _.isFinite(measureExtent[0]) ? Math.min(measureExtent[0], result[axis].extent[0]) : result[axis].extent[0];
                     result[axis].extent[1] = _.isFinite(measureExtent[1]) ? Math.max(measureExtent[1], result[axis].extent[1]) : result[axis].extent[1];
                 });
 
-                const countsTensorInRange = filterTensorOnTimestampRange(countsTensor, mainAxisLabel, countsTensor, timestampRange, includeEmptyBins);
+                const countsTensorInRange = filterTensorOnTimestampRange(countsTensor, mainAxisLabels, countsTensor, timestampRange, includeEmptyBins);
                 result.recordsCount = countsTensorInRange.reduce((currentCount, countInBin) => currentCount + countInBin, 0);
                 result.pointsCount = countsTensorInRange.length;
                 return result;
@@ -239,7 +253,14 @@
                 // We now have all the values we want we create the extent, mix can't have timestamp yet so we don't care of them
                 chartDef.genericMeasures.forEach((measure, measureIndex) => {
                     const tensorValues = ignoreForMeasure && ignoreForMeasure(measure) ? this.retrieveAggrData(chartData, valuesToCheckForColumns, measureIndex) : this.retrieveAggrData(chartData, valuesToCheckForLines, measureIndex);
-                    const measureExtent = d3.extent(tensorValues);
+                    let measureExtent = [];
+                    if (ChartMeasure.isRealUnaggregatedMeasure(measure)) {
+                        measureExtent = ChartMeasure.getUaMeasureExtent(this.retrieveUnaggrExtents(chartData, ignoreForMeasure && ignoreForMeasure(measure) ? valuesToCheckForColumns : valuesToCheckForLines, measureIndex));
+                    } else {
+                        measureExtent = d3.extent(tensorValues);
+                    }
+
+
                     const axis = measure.displayAxis === 'axis1' ? ChartsStaticData.LEFT_AXIS_ID : ChartsStaticData.RIGHT_AXIS_ID;
                     result[axis].onlyPercent = result[axis].onlyPercent && ChartDimension.isPercentScale([measure]);
                     result[axis].extent[0] = Math.min(measureExtent[0], result[axis].extent[0]);
@@ -259,6 +280,15 @@
                 }, []);
             },
 
+            retrieveUnaggrExtents: function(chartData, coordsArray, measureIndex) {
+                return coordsArray.reduce((acc, coords) => {
+                    const extents = chartData.getPointExtents(chartData.data.aggregations[measureIndex], Array.isArray(coords) ? coords : [coords]);
+                    acc.uaDataNegativeExtent.push(extents[0]);
+                    acc.uaDataPositiveExtent.push(extents[1]);
+                    return acc;
+                }, { uaDataNegativeExtent: [], uaDataPositiveExtent: [] });
+            },
+
             /**
              * Returns the min & max values across all dimensions for the given measure
              * @param {ChartTensorDataWrapper} chartData
@@ -320,12 +350,15 @@
              * @param {ChartTensorDataWrapper} chartData
              * @param {String} axisName: the name of the axis in chartData
              * @param {DimensionDef.java} dimension
+             * @param {{ ignoreLabels?: boolean, initialExtent?: [number, number] }} extraOptions
              * @return {Object} extent as {values: [], min: min, max: max}
              */
-            getAxisExtent: function(chartData, axisName, dimension, intialExtent = [Infinity, -Infinity], ignoreLabels = new Set()) {
+            getAxisExtent: function(chartData, axisName, dimension, extraOptions = {}) {
+                const ignoreLabels = extraOptions.ignoreLabels || new Set();
+                const initialExtent = extraOptions.initialExtent || [Infinity, -Infinity];
                 const labels = chartData.getAxisLabels(axisName);
-                let min = intialExtent[0];
-                let max = intialExtent[1];
+                let min = initialExtent[0];
+                let max = initialExtent[1];
 
                 const values = labels.filter(label => !ignoreLabels.has(label.label)).map(function(label) {
                     if (ChartDimension.isTimelineable(dimension)) {
@@ -355,7 +388,7 @@
              * @return {Object} extent as {values: [], min: min, max: max}
              */
             getUnaggregatedAxisExtentByType: function(uaDimensionType, axisData, afterFilterRecords) {
-                switch(uaDimensionType) {
+                switch (uaDimensionType) {
                     case 'str':
                         return {
                             values: angular.copy(axisData.str.sortedMapping)
@@ -473,7 +506,7 @@
                 if (chartType === CHART_TYPES.SCATTER_MULTIPLE_PAIRS) {
                     return svc.getScatterMPRecordsSummary(axisPairs, visibleCountMap);
                 } else {
-                    return `<strong>${ afterFilterRecords }</strong> ${translate('CHARTS.HEADER.RECORDS_REMAIN', 'records remain after applying filtering')}`;
+                    return `<strong>${afterFilterRecords}</strong> ${translate('CHARTS.HEADER.RECORDS_REMAIN', 'records remain after applying filtering')}`;
                 }
             },
 
@@ -508,7 +541,18 @@
                 }
                 return dateDisplayUnit;
             },
-            isPivotRequestAborted:  (errorData) => errorData && errorData.hasResult && errorData.aborted
+            isSameDay(minTimestamp, maxTimestamp) {
+                if (minTimestamp === undefined || maxTimestamp === undefined) {
+                    return false;
+                }
+
+                const minDate = new Date(minTimestamp);
+                const maxDate = new Date(maxTimestamp);
+                const minDateWrapper = moment(minDate).utc();
+                const maxDateWrapper = moment(maxDate).utc();
+                return minDateWrapper.year() === maxDateWrapper.year() && minDateWrapper.dayOfYear() === maxDateWrapper.dayOfYear();
+            },
+            isPivotRequestAborted: (errorData) => errorData && errorData.hasResult && errorData.aborted
         };
 
         return svc;
