@@ -51,7 +51,8 @@ const FLOW_QUICK_SHAREABLE_TYPES = [
     'DATASET',
     'MANAGED_FOLDER',
     'SAVED_MODEL',
-    'MODEL_EVALUATION_STORE'
+    'MODEL_EVALUATION_STORE',
+    'GENAI_EVALUATION_STORE',
 ];
 
 app.constant("FLOW_QUICK_SHAREABLE_TYPES", FLOW_QUICK_SHAREABLE_TYPES);
@@ -64,10 +65,18 @@ app.constant("FLOW_COMPUTABLE_TYPES", [
     'MANAGED_FOLDER',
     'SAVED_MODEL',
     'MODEL_EVALUATION_STORE',
+    'GENAI_EVALUATION_STORE',
     'STREAMING_ENDPOINT',
     'RETRIEVABLE_KNOWLEDGE'
 ]);
 
+// types of objects than can be manually added as dependencies of code agents and inline Python agent tools
+app.constant("FLOW_COMPUTABLE_DEPENDENCIES", [
+    'DATASET',
+    'SAVED_MODEL',
+    'RETRIEVABLE_KNOWLEDGE'
+]);
+
 // Publishable as insights on dashboards
 app.constant("PUBLISHABLE_TYPES", [
     'DATASET',
@@ -128,10 +137,14 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return 'SAVED_MODEL';
         } else if (nodeType.includes('MODELEVALUATIONSTORE') || nodeType.includes('MODEL_EVALUATION_STORE')) {
             return 'MODEL_EVALUATION_STORE';
+        } else if (nodeType.includes('GENAIEVALUATIONSTORE') || nodeType.includes('GENAI_EVALUATION_STORE')) {
+            return 'GENAI_EVALUATION_STORE';
         } else if (nodeType.includes('RETRIEVABLE_KNOWLEDGE')) {
             return 'RETRIEVABLE_KNOWLEDGE';
         } else if (nodeType.includes('MODEL_COMPARISON')) {
             return 'MODEL_COMPARISON';
+        } else if (nodeType.includes('GENAI_COMPARISON')) {
+            return 'GENAI_COMPARISON';
         } else if (nodeType.includes('PROMPT_STUDIO')) {
             return 'PROMPT_STUDIO';
         } else if (nodeType.includes('AGENT_TOOL')) {
@@ -173,7 +186,6 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
         } else if (nodeType == 'ARTICLE') {
             return 'ARTICLE';
         }
-
         throw new Error("Unhandled nodeType");
     };
 
@@ -203,7 +215,7 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
     this.fromListItem = function(listItem) {
         return {
             type: svc.taggableTypeFromAngularState(listItem),
-            projectKey: $stateParams.projectKey,
+            projectKey: listItem.projectKey || $stateParams.projectKey,
             id: listItem.id,
             displayName: listItem.name,
             subType: listItem.type,
@@ -239,12 +251,16 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return 'LABELING_TASK';
         } else if (stateName.startsWith('projects.project.managedfolders')) {
             return 'MANAGED_FOLDER';
-        } else if (stateName.startsWith('projects.project.savedmodels') || stateName.startsWith('projects.project.genai')) {
-            return 'SAVED_MODEL';
         } else if (stateName.startsWith('projects.project.modelevaluationstores')) {
             return 'MODEL_EVALUATION_STORE';
+        } else if (stateName.startsWith('projects.project.genaievaluationstores')) {
+            return 'GENAI_EVALUATION_STORE';
         } else if (stateName.startsWith('projects.project.modelcomparisons')) {
             return 'MODEL_COMPARISON';
+        } else if (stateName.startsWith('projects.project.genaicomparisons')) {
+            return 'GENAI_COMPARISON';
+        } else if (stateName.startsWith('projects.project.savedmodels') || stateName.startsWith('projects.project.genai')) {
+            return 'SAVED_MODEL';
         } else if (stateName.startsWith('projects.project.promptstudios')) {
             return 'PROMPT_STUDIO';
         } else if (stateName.startsWith('projects.project.agenttools')) {
@@ -255,7 +271,7 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return 'ANALYSIS';
         } else if (stateName.startsWith('projects.project.scenarios')) {
             return 'SCENARIO';
-        } else if (stateName.startsWith('projects.project.webapps') || stateName.startsWith('projects.project.dataikuanswers')) {
+        } else if (stateName.startsWith('projects.project.webapps') || stateName.startsWith('projects.project.agenthub') || stateName.startsWith('projects.project.traceexplorers')) {
             return 'WEB_APP';
         } else if (stateName.startsWith('projects.project.code-studios')) {
             return 'CODE_STUDIO';
@@ -278,7 +294,7 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
 
     this.isComputable = function(tor) {
         if (!tor) return;
-        return tor.type == 'DATASET' || tor.type == 'MANAGED_FOLDER' || tor.type == 'SAVED_MODEL' || tor.type == 'MODEL_EVALUATION_STORE' || tor.type == 'STREAMING_ENDPOINT';
+        return tor.type == 'DATASET' || tor.type == 'MANAGED_FOLDER' || tor.type == 'SAVED_MODEL' || tor.type == 'MODEL_EVALUATION_STORE' || tor.type == 'GENAI_EVALUATION_STORE' || tor.type == 'STREAMING_ENDPOINT';
     };
 
     this.isLocal = function(tor) {
@@ -294,8 +310,10 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return "folder";
         case "SAVED_MODEL":
             return "model";
+        case "GENAI_EVALUATION_STORE":
+            return "genai evaluation store";
         case "MODEL_EVALUATION_STORE":
-            return "evaluation store";
+            return "model evaluation store";
         case "LAMBDA_SERVICE":
             return "API service";
         default:
@@ -317,7 +335,7 @@ app.service("TaggableObjectsService", function($stateParams, $rootScope, $q, Dat
             modalScope.nrObjectsToDelete=0;
             modalScope.nrObjectsToUnshare=0;
 
-            //show dialog in delete and reconnect mode - set to true if any of deletionRequests are for a delete and reconnect (either they all are or none of them) 
+            //show dialog in delete and reconnect mode - set to true if any of deletionRequests are for a delete and reconnect (either they all are or none of them)
             modalScope.deleteAndReconnect = false;
             deletionRequests.forEach(function(dr) {
                 dr.options =  {...dr.options, ...{dropData: false}} ;
@@ -533,7 +551,7 @@ app.service("TaggableObjectsService", function($stateParams, $rootScope, $q, Dat
             const thumbnail = document.createElement('canvas');
             thumbnail.width = THUMBNAIL_WIDTH;
             thumbnail.height = THUMBNAIL_HEIGHT;
-            
+
             const imageData = canvas.getContext('2d').getImageData(0, 0, THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT);
             thumbnail.getContext('2d').putImageData(imageData, 0, 0);
             return thumbnail.toDataURL();
@@ -550,8 +568,11 @@ app.filter('niceTaggableType', function($filter, $translate) {
         'SAVED_MODEL': 'model',
         'LOCAL_SAVEDMODEL': 'model',
         'MODEL_EVALUATION_STORE': 'evaluation store',
+        'GENAI_EVALUATION_STORE': 'genai evaluation store',
         'LOCAL_MODEL_EVALUATION_STORE': 'evaluation store',
+        'LOCAL_GENAI_EVALUATION_STORE': 'genai evaluation store',
         'MODEL_COMPARISON': 'model comparison',
+        'GENAI_COMPARISON': 'genai comparison',
         'LAMBDA_SERVICE': 'API service',
         'SQL_NOTEBOOK': 'SQL notebook',
         'SEARCH_NOTEBOOK': 'Search notebook',
@@ -653,7 +674,7 @@ app.controller("DeleteTaggableObjectsModalController", function($scope, $state,
         $scope.commonTaggableType = TaggableObjectsUtils.getCommonType($scope.deletionRequests, function(x) {return x.type;});
 
         // Flow computables, publishable items and dashboards deletion can have impact
-        let typesWithImpact = PUBLISHABLE_TYPES.concat(FLOW_COMPUTABLE_TYPES).concat('DASHBOARD').concat('LABELING_TASK').concat('RETRIEVABLE_KNOWLEDGE');
+        let typesWithImpact = PUBLISHABLE_TYPES.concat(FLOW_COMPUTABLE_TYPES).concat('DASHBOARD').concat('LABELING_TASK').concat('RETRIEVABLE_KNOWLEDGE').concat('AGENT_TOOL');
         let computeImpact = $scope.deletionRequests.filter(function(x) {return typesWithImpact.indexOf(x.type) > -1;}).length > 0;
 
         if (computeImpact) {
@@ -664,7 +685,7 @@ app.controller("DeleteTaggableObjectsModalController", function($scope, $state,
                 $scope.nbActions = 0;
                 $scope.nbActionsNotRequested = 0;
                 for(let k in data.availableOptions) {
-                    
+
                     // Avoid counting actions on shared objects
                     let isShared = false
                     for (const o of data.toUnshare) {
@@ -826,9 +847,7 @@ app.controller('ListMassActionsCallbacks', function($scope, PIPELINEABILITY_ACTI
 });
 
 
-app.controller('_TaggableObjectsListPageCommon', function($controller, $scope, $filter, $state, $stateParams, $rootScope,
-    DataikuAPI, WT1, Fn,
-    TaggableObjectsService, TaggableObjectsUtils, TaggingService, InterestsService) {
+app.controller('_TaggableObjectsListPageCommon', function($controller, $scope, $stateParams, $rootScope, TaggableObjectsUtils, InterestsService) {
 
     $controller('ListMassActionsCallbacks', {$scope: $scope});
     $controller('_TaggableObjectsMassActions', {$scope: $scope});
@@ -897,6 +916,22 @@ app.controller('_TaggableObjectsListPageCommon', function($controller, $scope, $
         updateSelectedObjectMetadata(metaData);
     });
 
+    // for lists that can show foreign objects, foreign should be defined.
+    // For list that don't define foreign, it's assumed that it's because those list don't support foreign objects at all
+    $scope.containsForeignObject = function(listItems) {
+        return listItems && listItems.some(item => item.foreign)
+    }
+
+    $scope.enableForeignFilterWithLabels = ({all, onlyLocal, onlyForeign}, defaultFilterValue = '') => {
+        $scope.showForeignFilter = true;
+        $scope.showForeignOptions = [
+            { label: all, value: '' },
+            { label: onlyLocal, value: 'false' },
+            { label: onlyForeign, value: 'true' },
+        ];
+        $scope.selection.filterQuery.foreign = defaultFilterValue;
+    };
+
     $scope.allStarred = function(listItems) {
         if (!listItems || !listItems.length) return true;
         return listItems.map(x => !!(x && x.interest && x.interest.starred)).reduce((a,b) => a && b);
@@ -925,7 +960,7 @@ app.controller('_TaggableObjectsListPageCommon', function($controller, $scope, $
 
     /* Default list call */
     $scope.list = function() {
-        $scope.listHeads($stateParams.projectKey, $scope.tagFilter).success(function(data) {
+        return $scope.listHeads($stateParams.projectKey, $scope.tagFilter).success(function(data) {
             $scope.filteredOut = data.filteredOut;
             $scope.listItems = data.items;
             $scope.restoreOriginalSelection();
@@ -1031,7 +1066,7 @@ app.controller('_TaggableObjectsCapabilities', function($scope, TaggableObjectsC
 
 
 app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScope, $q, $stateParams, WT1, Logger, Dialogs, DataikuAPI, CreateModalFromTemplate,
-    TaggableObjectsService, TaggingService,
+    TaggableObjectsService, TaggingService, translate,
     ImpalaService, HiveService, SparkService, ComputablesService, DatasetsService, DatasetConnectionChangeService, SubFlowCopyService, RecipesEnginesService, ExposedObjectsService,
     GlobalProjectActions, RecipeDescService, FlowGraphSelection, FlowTool,
     InterestsService, InterestWording, WatchInterestState, TaggableObjectsUtils,
@@ -1077,7 +1112,11 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
 
     $scope.isWatching = WatchInterestState.isWatching;
     $scope.actionLabels = { ...InterestWording.labels };
-    $scope.actionTooltips = { ...InterestWording.tooltips };
+    $scope.actionTooltips = {
+        ...InterestWording.tooltips,
+        CANNOT_TAG_FOREIGN: translate('PROJECT.LIST_ITEMS.CANNOT_TAG_BECAUSE_FOREIGN', 'Shared objects cannot be tagged'),
+        CANNOT_CLEAR_FOREIGN: translate('PROJECT.LIST_ITEMS.CANNOT_CLEAR_BECAUSE_FOREIGN', 'Shared objects cannot be cleared'),
+    };
 
     $scope.shareObjectsInWorkspace = (items = $scope.getSelectedTaggableObjectRefs().map(tor => ({ reference: tor}))) => {
         CreateModalFromTemplate('/templates/dialogs/share-in-workspace.html', $scope, undefined, (newScope) => {
@@ -1250,7 +1289,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
             selectablePlugins: []
         };
 
-        if ($scope.isAllEvaluationStores || $scope.isAllModels) {
+        if ($scope.isAllEvaluationStores?.() || $scope.isAllModels?.()) {
             usability.recipes.r.ok = false;
             usability.recipes.shell.ok = false;
             usability.recipes.julia.ok = false;
@@ -1315,7 +1354,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
             onAction('action-build');
         }).error(setErrorInScope.bind($scope));
     }
-    
+
     $scope.startAllContinuous = function(objects) {
         WT1.event("start-continuous")
         CreateModalFromTemplate("/templates/continuous-activities/start-continuous-activity-modal.html", $scope, "StartContinuousActivityController", function(newScope) {
@@ -1349,14 +1388,14 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
                 let continuousActivityDone = beingBuilt && ((activity.mainLoopState || {}).futureInfo || {}).hasResult
                 states[activity.recipeId] = {beingBuilt: beingBuilt, continuousActivityDone: continuousActivityDone}
             });
-            
+
             var changes = 0;
             objects.forEach(function(o) {
                 let continuousActivityDone = (states[o.name] || {}).continuousActivityDone || false;
                 if (o.continuousActivityDone != continuousActivityDone) {
                     o.continuousActivityDone = continuousActivityDone;
                     changes += 1;
-                }                    
+                }
             });
             if (changes > 0) {
                 $rootScope.$broadcast("graphRendered");
@@ -1384,7 +1423,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
                 });
         }
     };
-    
+
 });
 
 
@@ -1410,7 +1449,8 @@ app.service("_SummaryHelper", function(
     Dialogs,
     WT1,
     InterestWording,
-    WatchInterestState
+    WatchInterestState,
+    translate
 ) {
     const svc = this;
 
@@ -1421,6 +1461,8 @@ app.service("_SummaryHelper", function(
             name : { editing: false, newVal: null, selector : ".name-edit-zone"},
             shortDesc : { editing: false, newVal: null, selector : ".shortdesc-edit-zone"},
             description : { editing: false, newVal: null, selector : ".desc-edit-zone"},
+            remarks : { editing: false, newVal: null, selector : ".desc-edit-zone"},
+            comment : { editing: false, newVal: null, selector : ".desc-edit-zone"},
             tags: {editing : false, newVal : null},
             projectStatus: {editing : false, newVal : null},
 
@@ -1574,16 +1616,23 @@ app.service("_SummaryHelper", function(
         $scope.addChecklist = function(index) {
             WT1.event("add-checklist", {objectType: $scope.objectType});
             const nChecklists = $scope.object.checklists.checklists.length;
+
+            const title = (
+                nChecklists
+                ? translate('SUMMARY_HELPER.ADD_CHECK_LIST.ITEM_NOT_FIRST.TITLE', "Todo list ({{ nChecklists }})", {nChecklists: nChecklists + 1})
+                : translate('SUMMARY_HELPER.ADD_CHECK_LIST.ITEM_FIRST.TITLE', "Todo list", {nChecklists: nChecklists + 1})
+            )
+
             $scope.object.checklists.checklists.push({
                 id: Math.floor(Math.random()*16777215).toString(16), //16777215 == ffffff
-                title:"Todo list"+(nChecklists ? ' '+(nChecklists+1) : ''),
+                title,
                 items: [],
                 $newlyCreated : true
             });
         };
 
         $scope.deleteChecklist = function(index) {
-            Dialogs.confirmSimple($scope, "Delete checklist").then(function() {
+            Dialogs.confirmSimple($scope, translate("SUMMARY_HELPER.DELETE_CHECKLIST.CONFIRM_MODAL.TITLE", "Delete checklist")).then(function() {
                 $scope.object.checklists.checklists.splice(index, 1);
                 $scope.$emit("objectSummaryEdited");
             });
@@ -1623,12 +1672,12 @@ app.service("_SummaryHelper", function(
 
         $scope.toggleWatch = function (event) {
             const currentState = $scope.data.interest.watching;
-            const nextState = (currentState === WatchInterestState.values.YES || currentState === WatchInterestState.values.SHALLOW) 
-                              ? WatchInterestState.values.ENO 
+            const nextState = (currentState === WatchInterestState.values.YES || currentState === WatchInterestState.values.SHALLOW)
+                              ? WatchInterestState.values.ENO
                               : WatchInterestState.values.YES;
             $scope.watchObject(nextState, event);
         };
-        
+
 
         $scope.watchObject = function(watch, event) {
             return InterestsService.watch($scope, getTaggableObjects(), watch)
@@ -1639,16 +1688,22 @@ app.service("_SummaryHelper", function(
                         $scope.objectType,
                         $stateParams.projectKey,
                         $scope.getObjectId(),
-                        $stateParams.workspaceKey 
+                        $stateParams.workspaceKey
                     ).success(function(newInterest) {
-                        $scope.data.interest.nbWatching = newInterest.nbWatching;
-                        $scope.data.interest.watching = newInterest.watching;
+                        if ($scope.objectInterest) {
+                            $scope.objectInterest.nbWatching = newInterest.nbWatching;
+                            $scope.objectInterest.watching = newInterest.watching;
+                        }
+                        if ($scope.data?.interest) {
+                            $scope.data.interest.watching = newInterest.watching;
+                            $scope.data.interest.nbWatching = newInterest.nbWatching;
+                        }
 
                         if (event) $scope.refreshTooltip(event);
                     });
                 });
         };
-        
+
 
         $scope.starObject = function(star, event) {
             return InterestsService.star($scope, getTaggableObjects(), star)
@@ -1661,15 +1716,21 @@ app.service("_SummaryHelper", function(
                         $scope.getObjectId(),
                         $stateParams.workspaceKey
                     ).success(function (newInterest) {
-                        $scope.data.interest.nbStarred = newInterest.nbStarred;
-                        $scope.data.interest.starred = newInterest.starred;
-        
+                        if ($scope.objectInterest) {
+                            $scope.objectInterest.nbStarred = newInterest.nbStarred;
+                            $scope.objectInterest.starred = newInterest.starred;
+                        }
+                        if ($scope.data?.interest) {
+                            $scope.data.interest.starred = newInterest.starred;
+                            $scope.data.interest.nbStarred = newInterest.nbStarred;
+                        }
+
                         if (event) $scope.refreshTooltip(event);
                     });
                 });
         };
-        
-        
+
+
         $scope.isWatching = WatchInterestState.isWatching;
         $scope.actionLabels = { ...InterestWording.labels };
 
@@ -1693,7 +1754,7 @@ app.service("_SummaryHelper", function(
                 modalScope.title = users.length + " user"+(users.length>1?'s':'')+" starred this object";
                 CreateModalFromTemplate("/templates/interested-users.html", modalScope);
             }).error(setErrorInScope.bind($scope));
-        };    
+        };
 
         //TODO : hesitated with adding this directly to the tooltip directive... can change
         $scope.refreshTooltip = function(event) {
@@ -1702,8 +1763,8 @@ app.service("_SummaryHelper", function(
               .attr('data-original-title', el.attr('title'))
               .tooltip('show');
         };
-        
-        
+
+
     };
 });
 
@@ -1738,6 +1799,8 @@ app.directive('editableSummary', function(DatasetsService, DataikuAPI, $statePar
                 return null;
             };
 
+            $scope.typeBadgeList = $scope.object.typeBadges ? Object.keys($scope.object.typeBadges) : [];
+
             _SummaryHelper.addEditBehaviour($scope, element);
             _SummaryHelper.addInterestsManagementBehaviour($scope);
 
@@ -1763,11 +1826,12 @@ app.directive('editableSummary', function(DatasetsService, DataikuAPI, $statePar
                 $scope.$emit('customFieldsSummaryEdited', customFields);
             };
 
-            $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
+            const customFieldsSavedUnsubscribe = $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
                 if (TopNav.sameItem(TopNav.getItem(), item)) {
                     $scope.object.customFields = newCustomFields;
                 }
             });
+            $scope.$on('$destroy', customFieldsSavedUnsubscribe);
         }
     };
 });
@@ -1806,11 +1870,12 @@ app.directive('editableProjectSummary', function(
                 $scope.$emit('customFieldsSummaryEdited', customFields);
             };
 
-            $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
+            const customFieldsSavedUnsubscribe = $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
                 if (TopNav.sameItem(TopNav.getItem(), item)) {
                     $scope.object.customFields = newCustomFields;
                 }
             });
+            $scope.$on('$destroy', customFieldsSavedUnsubscribe);
 
             $scope.generateDescription = function() {
                 $scope.generateDescriptionForObject().then(function(description) {
@@ -1979,11 +2044,13 @@ app.directive('customFieldsInSidePanel', function($rootScope, Logger, PluginConf
                 PluginConfigUtils.setDefaultValues(customFieldsMapFlattenList, $scope.ui.customFields);
             });
 
-            $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
+            const customFieldsSavedUnsubscribe = $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
                 if (TopNav.sameItem(TopNav.getItem(), item)) {
                     $scope.ui.customFields = newCustomFields;
                 }
             });
+            $scope.$on('$destroy', customFieldsSavedUnsubscribe);
+
         }
     };
 });
