@@ -35,7 +35,7 @@ class DkuGluonTSEstimator(BaseTimeseriesEstimator):
     """
         Contains the GluonTS predictor, external features and several model & algo specific parameters. 
         
-        /!\ From release 11.2 to 12.0 (included), only predictor and external_features were serialized and params
+        /! From release 11.2 to 12.0 (included), only predictor and external_features were serialized and params
         needed for scoring/evaluation were set via the initialize method.
         We still need to use the initialize method for backward compatibility.
     """
@@ -179,7 +179,7 @@ class DkuGluonTSEstimator(BaseTimeseriesEstimator):
         self.use_timeseries_identifiers_as_features = False
         self.monthly_day_alignment = get_monthly_day_alignment(core_params)
 
-    def fit(self, train_df, external_features=None):
+    def fit(self, train_df, external_features=None, shift_map=None):
         raise NotImplementedError()
 
     def _prepare_predict(self):
@@ -373,7 +373,7 @@ class DkuGluonTSDeepLearningEstimator(DkuGluonTSEstimator):
     def _get_estimator(self, train_data, identifier_cardinalities):
         raise NotImplementedError()
 
-    def fit(self, train_df, external_features=None):
+    def fit(self, train_df, external_features=None, shift_map=None):
         if external_features is not None:
             self.external_features = external_features
 
